This folder contains authentication modules (plugins) for applications
to add two factor authentication with privacyIDEA to these
applications.

Each authentication module plugs into the existing application and
forwards the the credentials to privacyIDEA using the REST API.

The REST API is documented at http://privacyidea.readthedocs.org/en/latest/modules/api.html.

Further plugins for Wordpress, Contao, Django and Dokuwiki are available at https://github.com/cornelinux?tab=repositories.
